==> common-0.0.7-sources.jar: com/microsoft/identity/common/internal/providers/microsoft/microsoftsts/MicrosoftStsAuthorizationErrorResponse.java <==
// Copyright (c) Microsoft Corporation.
// All rights reserved.
//
// This code is licensed under the MIT License.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files(the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and / or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions :
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
package com.microsoft.identity.common.internal.providers.microsoft.microsoftsts;

import com.microsoft.identity.common.internal.providers.microsoft.MicrosoftAuthorizationErrorResponse;

/**
 * Sub class of {@link MicrosoftAuthorizationErrorResponse}.
 * Encapsulates Microsoft STS specific Authorization Result errors in addition to Microsoft error parameters.
 */
public class MicrosoftStsAuthorizationErrorResponse extends MicrosoftAuthorizationErrorResponse {

    /**
     * Constructor of {@link MicrosoftStsAuthorizationErrorResponse}.
     *
     * @param error            Error string returned from the Authorization Server.
     * @param errorDescription Description string of the error.
     */
    public MicrosoftStsAuthorizationErrorResponse(final String error, final String errorDescription) {
        super(error, errorDescription);
    }

}

==> common-3.6.0-sources.jar: com/microsoft/identity/common/internal/providers/microsoft/microsoftsts/MicrosoftStsAuthorizationErrorResponse.java <==
// Copyright (c) Microsoft Corporation.
// All rights reserved.
//
// This code is licensed under the MIT License.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files(the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and / or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions :
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
package com.microsoft.identity.common.internal.providers.microsoft.microsoftsts;

import com.microsoft.identity.common.internal.providers.microsoft.MicrosoftAuthorizationErrorResponse;

/**
 * Sub class of {@link MicrosoftAuthorizationErrorResponse}.
 * Encapsulates Microsoft STS specific Authorization Result errors in addition to Microsoft error parameters.
 */
public class MicrosoftStsAuthorizationErrorResponse extends MicrosoftAuthorizationErrorResponse {
    private String mErrorSubcode;

    /**
     * Constructor of {@link MicrosoftStsAuthorizationErrorResponse}.
     *
     * @param error            Error string returned from the Authorization Server.
     * @param errorDescription Description string of the error.
     */
    public MicrosoftStsAuthorizationErrorResponse(final String error, final String errorDescription) {
        super(error, errorDescription);
    }

    /**
     * Constructor of {@link MicrosoftStsAuthorizationErrorResponse}.
     *
     * @param error            Error string returned from the Authorization Server.
     * @param errorSubcode     Error subcode string return from the Authorization Server.
     * @param errorDescription Description string of the error.
     */
    public MicrosoftStsAuthorizationErrorResponse(final String error,
                                                  final String errorSubcode,
                                                  final String errorDescription) {
        super(error, errorDescription);
        mErrorSubcode = errorSubcode;
    }

    public String getErrorSubcode() {
        return mErrorSubcode;
    }

    public void setErrorSubcode(String errorSubcode) {
        mErrorSubcode = errorSubcode;
    }


}
